Crate pharia_skill

Crate pharia_skill 

Structs

ChatParams
ChatRequest
ChatResponse
ChunkParams
Chunking parameters
ChunkRequest
Completion
The result of a completion, including the text generated as well as why the model finished completing.
CompletionParams
Completion request parameters
CompletionRequest
Parameters required to make a completion request.
Distribution
Document
DocumentPath
Location of a document in the search engine
IndexPath
Which documents you want to search in, and which type of index should be used
Logprob
Message
MetadataFilter
SearchRequest
SearchResult
Result to a search query
SelectLanguageRequest
TextCursor
TokenUsage

Enums

FilterCondition
FinishReason
The reason that the model stopped completing text
LanguageCode
Logprobs
MetadataFieldValue
MetadataFilterCondition
Modality
ModalityType
SearchFilter

Traits

Csi
Cognitive System Interface

Attribute Macros

skill
Macro to define a Skill. It wraps a function that takes a single argument and returns a single value. Macro to define a Skill. It wraps a function that takes a single argument and returns a single value.