#[skill]Expand description
Macro to define a Skill. It wraps a function that takes a single argument and returns a single value. Macro to define a Skill. It wraps a function that takes a single argument and returns a single value.
The argument should implement serde::Deserialize to process an incoming JSON body, and the return value should implement serde::Serialize to return a JSON body.
Both also need to implement schemars::JsonSchema to generate a JSON schema for the input and output.
You can use the #[derive(schemars::JsonSchema)] attribute to automatically implement JsonSchema for your types.
Also, the doc comment can be used to provide a description of the skill.