LanguageCode

Enum LanguageCode 

pub enum LanguageCode {
Show 75 variants Afr, Ara, Aze, Bel, Ben, Bos, Bul, Cat, Ces, Cym, Dan, Deu, Ell, Eng, Epo, Est, Eus, Fas, Fin, Fra, Gle, Guj, Heb, Hin, Hrv, Hun, Hye, Ind, Isl, Ita, Jpn, Kat, Kaz, Kor, Lat, Lav, Lit, Lug, Mar, Mkd, Mon, Mri, Msa, Nld, Nno, Nob, Pan, Pol, Por, Ron, Rus, Slk, Slv, Sna, Som, Sot, Spa, Srp, Sqi, Swa, Swe, Tam, Tel, Tgl, Tha, Tsn, Tso, Tur, Ukr, Urd, Vie, Xho, Yor, Zho, Zul,
}

Variants



Afr

Afrikaans -



Ara

Arabic -



Aze

Azerbaijani -



Bel

Belarusian -



Ben

Bengali -



Bos

Bosnian -



Bul

Bulgarian -



Cat

Catalan -



Ces

Czech -



Cym

Welsh -



Dan

Danish -



Deu

German -



Ell

Greek -



Eng

English -



Epo

Esperanto -



Est

Estonian -



Eus

Basque -



Fas

Persian -



Fin

Finnish -



Fra

French -



Gle

Irish -



Guj

Gujarati -



Heb

Hebrew -



Hin

Hindi -



Hrv

Croatian -



Hun

Hungarian -



Hye

Armenian -



Ind

Indonesian -



Isl

Icelandic -



Ita

Italian -



Jpn

Japanese -



Kat

Georgian -



Kaz

Kazakh -



Kor

Korean -



Lat

Latin -



Lav

Latvian -



Lit

Lithuanian -



Lug

Ganda -



Mar

Marathi -



Mkd

Macedonian -



Mon

Mongolian -



Mri

Maori -



Msa

Malay -



Nld

Dutch -



Nno

Norwegian Nynorsk -



Nob

Norwegian Bokmål -



Pan

Punjabi -



Pol

Polish -



Por

Portuguese -



Ron

Romanian -



Rus

Russian -



Slk

Slovak -



Slv

Slovene -



Sna

Shona -



Som

Somali -



Sot

Sotho -



Spa

Spanish -



Srp

Serbian -



Sqi

Albanian -



Swa

Swahili -



Swe

Swedish -



Tam

Tamil -



Tel

Telugu -



Tgl

Tagalog -



Tha

Thai -



Tsn

Tswana -



Tso

Tsonga -



Tur

Turkish -



Ukr

Ukrainian -



Urd

Urdu -



Vie

Vietnamese -



Xho

Xhosa -



Yor

Yoruba -



Zho

Chinese -



Zul

Zulu -