pub struct ChatParams {
pub max_tokens: Option<u32>,
pub temperature: Option<f64>,
pub top_p: Option<f64>,
pub frequency_penalty: Option<f64>,
pub presence_penalty: Option<f64>,
pub logprobs: Logprobs,
}Fields
max_tokens: Option<u32>The maximum tokens that should be inferred.
Note: the backing implementation may return less tokens due to other stop reasons.
temperature: Option<f64>The randomness with which the next token is selected.
top_p: Option<f64>The probability total of next tokens the model will choose from.
frequency_penalty: Option<f64>When specified, this number will decrease (or increase) the probability of repeating tokens that were mentioned prior in the completion. The penalty is cumulative. The more a token is mentioned in the completion, the more its probability will decrease. A negative value will increase the likelihood of repeating tokens.
presence_penalty: Option<f64>The presence penalty reduces the probability of generating tokens that are already present in the generated text respectively prompt. Presence penalty is independent of the number of occurrences. Increase the value to reduce the probability of repeating text.
logprobs: LogprobsUse this to control the logarithmic probabilities you want to have returned. This is useful to figure out how likely it had been that this specific token had been sampled.