pub struct ChunkParams {
pub model: String,
pub max_tokens: u32,
pub overlap: u32,
}Expand description
Chunking parameters
Fields
model: StringThe name of the model the chunk is intended to be used for. This must be a known model.
max_tokens: u32The maximum number of tokens that should be returned per chunk.
overlap: u32The amount of allowed overlap between chunks. overlap must be less than max-tokens.
Implementations