pub struct Completion {
pub text: String,
pub finish_reason: FinishReason,
pub logprobs: Vec<Distribution>,
pub usage: TokenUsage,
}Expand description
The result of a completion, including the text generated as well as why the model finished completing.
Fields
text: StringThe text generated by the model
finish_reason: FinishReasonThe reason the model finished generating
logprobs: Vec<Distribution>Contains the logprobs for the sampled and top n tokens, given that
completion-request.params.logprobs has been set to sampled or top.
usage: TokenUsageUsage statistics for the completion request.