pub struct IndexPath {
pub namespace: String,
pub collection: String,
pub index: String,
}Expand description
Which documents you want to search in, and which type of index should be used
Fields
namespace: StringThe namespace the collection belongs to
collection: StringThe collection you want to search in
index: StringThe search index you want to use for the collection
Implementations